@@ -4,18 +4,17 @@
 #ifndef __DANLIB__
 #define __DANLIB
 
-#include "proto.h"
 #include <stdio.h>
 
 #define CHAR2NUM(x) ((x) - '0')
 #define LAST_INDEX(x) (sizeof x / sizeof x[0])
 #define strEQ(X,Y) (0 == strcmp((X),(Y)))
 
-void initStr PROTO((char **, int));
-int isAllNums PROTO((char *));
-char *numSuffix PROTO((int));
-char *hc_itoa PROTO((int));
-int istrncasecmp PROTO((int,char *,char *));
-int lookup_string PROTO((char *str, char *arr[], int size, int len));
+void initStr( char **, size_t );
+int isAllNums( const char * );
+const char *numSuffix( int );
+char *hc_itoa( int );
+int istrncasecmp( size_t,const char *,const char * );
+int lookup_string( const char *str, const char *arr[], int size, int len );
 
 #endif
