@@ -3,9 +3,8 @@
 */
 #ifndef MYGETOPT_H
 #define MYGETOPT_H
-#include "proto.h"				/* define PROTO */
 
-int Getopt PROTO((int, char **, char *,int));
+int Getopt(int, char **, char *,int);
 extern char *Optarg;				/* current argv string */
 extern int Optind;				/* current argv index */
 extern int Optopt;				/* option character */
